@@ -6,13 +6,17 @@ function(x, coords, label.areas=NULL,
     label.areas <- as.character(1:n)
   gr.lab <- unique(x$groups)
   if (missing(groups.colors))
-    groups.colors <- rainbow(length(gr.lab))
+    if (getRversion() >= "3.6.0") {
+      groups.colors <- hcl.colors(length(gr.lab), "Set 2")
+    } else {
+      groups.colors <- terrain.colors(length(gr.lab))
+    }
   symbols(coords[,1], coords[,2], circles=rep(cex.circles,n),
           inches=FALSE, xlab=" ", ylab=" ", xaxt="n", yaxt="n",
           fg=groups.colors[x$groups], ...)
   id.edgp <- which(sapply(x$edges.groups, function(x)
-                          length(x$node))>1)
-  if (length(id.edgp)>0)
+                          length(x$node))>1L)
+  if (length(id.edgp)>0L)
     for (i in 1:length(id.edgp)) {
       id1 <- x$edges.groups[[id.edgp[i]]]$edge[,1]
       id2 <- x$edges.groups[[id.edgp[i]]]$edge[,2]
